@@ -15,7 +15,7 @@ import urllib3  # type: ignore
 from selenium import webdriver  # type: ignore
 from selenium.webdriver import ChromeOptions  # type: ignore
 from webdriver_manager.chrome import ChromeDriverManager  # type: ignore
-from webdriver_manager.driver import Driver  # type: ignore
+from webdriver_manager.core.driver import Driver  # type: ignore
 
 from open_webdriver.download_chromium import get_chromium_exe
 from open_webdriver.path import LOG_FILE, WDM_DIR
@@ -33,12 +33,11 @@ CACHE_TIMEOUT_DAYS = 7
 
 os.makedirs(WDM_DIR, exist_ok=True)
 LOCK_FILE = os.path.join(WDM_DIR, "lock.file")
-LOCK = filelock.FileLock(LOCK_FILE)
 
 INSTALL_TIMEOUT = float(60 * 10)  # Upto 10 minutes of install time.
 
 
-def open_webdriver(  # pylint: disable=too-many-arguments
+def open_webdriver(  # pylint: disable=too-many-arguments,too-many-branches
     headless: bool = True,
     verbose: bool = False,  # pylint: disable=unused-argument
     timeout: float = INSTALL_TIMEOUT,
@@ -70,21 +69,28 @@ def open_webdriver(  # pylint: disable=too-many-arguments
             opts.add_argument("--disable-gpu")
     if user_agent:
         opts.add_argument(f"--user-agent={user_agent}")
-    with LOCK.acquire(timeout=timeout):
-        if sys.platform != "darwin":
-            if verbose:
-                print("  Installing web driver...")
-            chromium_exe = get_chromium_exe()
-            if verbose:
-                print("  Finished installing web driver: ", chromium_exe)
-            opts.binary_location = chromium_exe
+    lock = filelock.FileLock(LOCK_FILE)
+    with lock.acquire(timeout=timeout):
+        if verbose:
+            print("  Installing web driver...")
+        chromium_exe = get_chromium_exe()
+        if verbose:
+            print("  Finished installing web driver: ", chromium_exe)
+        opts.binary_location = chromium_exe
+        version = "101.0.4951.41"
         driver_path = ChromeDriverManager(
-            cache_valid_range=CACHE_TIMEOUT_DAYS, version="101.0.4951.41", path=WDM_DIR
+            cache_valid_range=CACHE_TIMEOUT_DAYS,
+            version=version,
+            path=WDM_DIR
         ).install()
     if verbose:
         print(f"\n  Using ChromeDriver: {driver_path}")
     try:
-        driver = webdriver.Chrome(driver_path, options=opts, service_log_path=LOG_FILE)
+        driver = webdriver.Chrome(
+            driver_path,
+            options=opts,
+            service_log_path=LOG_FILE
+        )
         return driver
     except Exception as err:  # pylint: disable=broad-except
         traceback.print_exc()
